@@ -1,15 +1,15 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) Polyconseil SAS. All rights reserved.
 
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import sys
 import warnings
 
-import pkg_resources
+try:
+    from importlib import metadata
+except ImportError:
+    # Python<3.8: use importlib-metadata package
+    import importlib_metadata as metadata  # type: ignore
 
-__version__ = pkg_resources.get_distribution('grocker').version
+__version__ = metadata.version('grocker')
 __copyright__ = '2015, Polyconseil'
 
 
